tests.models.output.types package — django_analyses 0.0.3 documentation

# tests.models.output.types package

## Submodules

## tests.models.output.types.test_file_output module

class `tests.models.output.types.test_file_output.` `FileOutputTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `FileOutput` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_get_type`()
  `test_key`()
  `test_string`()

## tests.models.output.types.test_float_output module

class `tests.models.output.types.test_float_output.` `FloatOutputTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `FloatOutput` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_get_type`()
  `test_key`()
  `test_string`()

## Module contents